unit wrapi;

interface

uses WinTypes, WinProcs;

const
  MAX_DEVNAME = 64;
  {$IFNDEF WIN32}
  MAX_PATH = 260;
  {$ENDIF}


  { Features (capabilities) }

  RIF_USVERSION = $00000001;    { Set if hardware is US version }
  RIF_DSP       = $00000002;    { Set if there is a DSP on the card }
  RIF_LSBUSB    = $00000004;    { Set if has CW/LSB/USB instead of SSB }
  RIF_CWIFSHIFT = $00000008;    { Set if the receiver uses IFShift instead of BFO in CW mode }
  RIF_SQUELCH   = $00000010;    { Set if the receiver supports squelch control }
  RIF_BLOCKSCAN = $00000020;    { Set if the receiver supports block scanning }
  RIF_AGC       = $00000100;    { Set if the AGC can be turned on or off }
  RIF_IFGAIN    = $00000200;    { Set if the IF gain can be adjusted }
  RIF_ADJAGC    = $00000400;    { Set if the AGC time constant can be adjusted }
  RIF_PREAMP    = $00000800;    { Set if the receiver has a switchable preamp }

  RIF_FMSTEREO  = $00001000;    { Set if the receiver supports FMW stereo reception }
  RIF_AMSTEREO  = $00002000;    { Set if the receiver support AM stereo reception }
  RIF_AUDIOCAP  = $00010000;    { Set if the hardware has Hi-Fi audio capture factilities }
  RIF_VIDEOCAP  = $00020000;    { Set if the hardware has video capture factilities }

  { WiNRADiO Hardware Versions }

  VER_STANDARD  = $100;         { old, obsolete constants }
  VER_STANDARD2 = $10A;
  VER_SPECMON   = $200;

  RHV_1000a     = $100;   { v1.00 (standard receiver) }
  RHV_1000b     = $10A;   { v1.10 (standard with better FMW signal strength) }
  RHV_1200      = $114;   { v1.20 (FMW only receiver) }
  RHV_1500      = $132;   { v1.50 (1000b with new BFO and LSB/USB) }
  RHV_1550      = $137;   { v1.55 (Series II 1500) }
  RHV_3000      = $200;   { v2.00 (Spectrum Monitor edition) }
  RHV_3100      = $20A;   { v2.10 (3000 with new BFO) }
  RHV_3150      = $20F;   { v2.15 (Series II 3100) }
  RHV_3200      = $214;   { v2.20 (Series II 2000 + FM6 + SSB filter + 1.6GHz) }
  RHV_3500      = $232;   { v2.50 (3200 + 2.6GHz down converter) }
  RHV_3700      = $246;   { v2.70 (3200 + 4GHz down converter) }
  RHV_2000      = $300;   { v3.00 (Series II + FMM + adj IF gain) }
  RHV_2902      = $35C;   { v3.92 (Sonobuoy 1550) }

  RHV_4000      = $400;   { v4.00 (base model 4000 series) }

  { Modes }  { bit 1 set = FM mode! (mode and RMD_FMN <> 0) }

  RMD_SSB   = 0;         { standard card mode }
  RMD_CW    = RMD_SSB;   { pro card mode }
  RMD_AM    = 1;
  RMD_FMN   = 2;
  RMD_FMW   = 3;
  RMD_LSB   = 4;
  RMD_USB   = 5;
  RMD_FMM   = 6;

  { Mode Bandwidths }

  RBW_DEFAULT = 0;
  RBW_500     = $0100;  { default for CW }
  RBW_2500    = $0200;  { default for LSB/USB (and CW in WR-3000) }
  RBW_6k      = $0300;  { default for AM (and SSB in WR-1000) }
  RBW_12k     = $0400;
  RBW_17k     = $0500;  { default for FMN }
  RBW_50k     = $0600;  { default for FMM }
  RBW_280k    = $0700;  { default for FMW }

  { Hardware interfaces }

  RHI_ISA       = 0;  { Standard jumpered ISA card }
  RHI_SERIAL    = 1;  { Serial connection through serial port }
  RHI_PCMCIA    = 2;  { PCCard (PCMCIA) connection }
  RHI_USB       = 3;  { Universal Serial Bus (1.5Mb) connection }
  RHI_NETWORK   = 4;  { Ethernet or remote connection }
  RHI_PCI       = 5;  { PCI card }
  RHI_PnPISA    = 6;  { Plug-n-Play ISA card }

  { Audio sources }

  RAS_RADIO     = 0;
  RAS_DSP       = 1;

  { DSP input sources }

  RDS_RADIO     = 0;
  RDS_DATA      = 1;

  { Wave formats (used in dspIn/OutOpen functions and TRadioInfo.dwWaveFormats) }
  RWF_8kHz      = $00000001;
  RWF_11kHz     = $00000002;
  RWF_16kHz     = $00000004;
  RWF_22kHz     = $00000008;
  RWF_44kHz     = $00000020;
  RWF_48kHz     = $00000040;
  RWF_64kHz     = $00000100;
  RWF_96kHz     = $00001000;

  RWF_8bit      = $00010000;
  RWF_16bit     = $00020000;
  RWF_24bit     = $00040000;

  RWF_Mono      = $01000000;
  RWF_Stereo    = $02000000;

  { DSP Notification messages }

  RM_DSPREQ       = $7F00;
  RM_DSPACKWRITE  = $7F01;
  RM_DSPACKREAD   = $7F02;
  RM_DSPREQWRITE  = $7F03;
  RM_DSPREQREAD   = $7F04;
  RM_DSPPAUSED    = $7F05;
  RM_DSPRESUMED   = $7F06;

  { Radio notifications }
  RM_RADIOADDED   = $7F10;
  RM_RADIOREMOVED = $7F11;

  { Asynchronous notifications }
  RM_SLEVELNOTIFY = $7F20;
  RM_CALLFAILED   = $7F21;
  RM_STATUS       = $7F22;  { any flags set indicate a failure of a signal }

  { ADU notifications }
  RM_ADURECEIVER  = $7F80;  { A receiver has changed antenna connection }
  RM_ADUANTENNA   = $7F81;  { An antennas configuration has changed }
  RM_ADUFOUND     = $7F82;  { An ADU has been started/connected, info can be obtained }
  RM_ADUREMOTE    = $7F83;  { An ADU has changed remote mode status }
  RM_ADUCONNECT   = $7F84;  { An ADU has changed connection status }

  { ADU status flags }
  AS_REMOTEMODE   = $0001;  { The ADU is in remote mode }
  AS_CONNECTED    = $0002;  { The ADU is connected and operational }

  { ADU antenna status flags }
  AAS_FILTER       = $0001;
  AAS_ATTEN        = $0002;
  AAS_PREAMP       = $0004;

  { Radio Status flags (WM_STATUS) }
  RS_SQUELCH      = $0001;  { high if the squelch is active }
  RS_PLL          = $0004;  { high if PLL is locked }
  RS_CONNECTION   = $0008;  { high if receiver is not connected to interface }
  RS_VCC          = $0010;  { high if power is not connected to receiver }

  { Set/GetFrequency contant }
  RFQ_X10       = $80000000;

type
  PModeList = ^TModeList;
  TModeList = array [0..999] of Integer;

  PRadioInfo = ^TRadioInfo;
  TRadioInfo = packed record
    dwSize: Longint;            { size of structure }
    dwFeatures: Longint;        { bit flags for extra features }
    wAPIVer: Word;              { driver version }
    wHWVer: Word;               { hardware version }
    dwMinFreq: Longint;         { minimum frequency receiver can tune to }
    dwMaxFreq: Longint;         { maximum frequency receiver can tune to }
    iFreqRes: Integer;          { resolution of receiver in Hz }
    iNumModes: Integer;         { number of modes that can be set }
    iMaxVolume: Integer;        { maximum volume level }
    iMaxBFO: Integer;           { maximum BFO offset range (+/- in Hz) }
    iMaxFMScanRate: Integer;    { maximum scan rate for FM scanning/sweeping }
    iMaxAMScanRate: Integer;    { maximum scan rate for AM scanning/sweeping }
    iHWInterface: Integer;      { hardware interface used (or IO address) }
    iDeviceNum: Integer;        { device number }
    iNumSources: Integer;       { number of selectable audio sources }
    iMaxIFShift: Integer;       { IF shift tuning range }
    dwWaveFormats: Longint;     { DSP wave formats suppoted }
    iDSPSources: Integer;       { number of selectable DSP input sources }
    lpSupportedModes: PModeList;{ pointer to list of supported mode/bandwidth combos }
    dwMaxFreqkHz: Longint;      { the maximum receiver frequency in kHz }
    szDeviceName: array [0..MAX_DEVNAME-1] of Char; { shortly! }
    iMaxIFGain: Integer;
    dwSquelchFlags: Longint;    { combination of SPU_XXX flags for squelch support }
  end;

  PDSPHdr = ^TDSPHdr;
  TDSPHdr = record
    lpData: PChar;
    dwBufferLength: Longint;
    dwBytesTransferred: Longint;
    dwUser: Longint;
    dwFlags: Longint;
    dwDateTransferred: Longint;
    dwTimeTransferred: Longint;
  end;

  TRMDSPReq = record
    Msg: Cardinal;
    hRadio: Cardinal;
    dwReqCode: Longint;
    Result: Longint;
  end;

  TRMDMAAckRead = record
    Msg: Cardinal;
    hRadio: Cardinal;
    lpDSPHdr: PDSPHdr;
    Result: Longint;
  end;

  TRMDMAAckWrite = TRMDMAAckRead;

  TRMDMAReqRead = record
    Msg: Cardinal;
    hRadio: Cardinal;
    dwLength: Longint;
    Result: Longint;
  end;

  TRMDMAReqWrite = TRMDMAReqRead;

  TRMRadioAdded = record
    Msg: Cardinal;
    wDevNum: Cardinal;
    dwInterface: Longint;
    Result: Longint;
  end;

  TAduAntennaInfo = record
    dwLowFreqkHz: Longint;        { designed low frequency point of antenna }
    dwHighFreqkHz: Longint;       { designed high frequency point of antenna }
    dwLowFilterFreqkHz: Longint;  { low frequency of bandstop filter }
    dwHighFilterFreqkHz: Longint; { high frequency of bandstop filter }
    dwAtten: Longint;             { attenuator in dB (0 = not supported) }
    fHasPreamp: LongBool;         { antenna supports switchable preamplifier supply }
  end;

  PAduInfo = ^TAduInfo;
  TAduInfo = record
    iNumReceivers: Longint;
    iNumAntennas: Longint;
    szAduName: array [0..MAX_DEVNAME-1] of Char;  
    aiAntennaInfo: array [0..3] of TAduAntennaInfo;
  end;

var
  OpenRadioDevice: function (iDeviceNum: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  CloseRadioDevice: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetRadioDeviceInfo: function (hRadio: Integer; lpInfo: PRadioInfo): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetSignalStrength: function (hRadio: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetRawSignalStrength: function (hRadio: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
  LoadCalibrationData: procedure (hRadio: Integer); {$IFDEF WIN32} stdcall; {$ENDIF}

  SetFrequency: function (hRadio: Integer; dwFreq: Longint): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetMode: function (hRadio, iMode: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetVolume: function (hRadio, iVolume: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetAtten: function (hRadio: Integer; fAtten: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetMute: function (hRadio: Integer; fMute: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetPower: function (hRadio: Integer; fPower: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetScanMode: function (hRadio: Integer; fScan: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetBFOOffset: function (hRadio, iBFO: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetIFShift: function (hRadio, iIFShift: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetAudioSource: function (hRadio, iSource: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetDSPSource: function (hRadio, iSource: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetAGC: function (hRadio, iAGC: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  SetIFGain: function (hRadio, iIFGain: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}

  GetFrequency: function (hRadio: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetMode: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetVolume: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetAtten: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetMute: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetPower: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetScanMode: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetBFOOffset: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetIFShift: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetAudioSource: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetDSPSource: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetAGC: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetIFGain: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}

  { API functions for DSP }

  dspOpen: function (hRadio: Integer; lpBootCode: Pointer; hWindow: HWND): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspClose: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspSendByte: function (hRadio: Integer; bData: Byte): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspReadByte: function (hRadio: Integer; var lpbData: Byte): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspOutWrite: function (hRadio: Integer; lpDSPHeader: PDSPHdr; cbDSPHeader: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspInAddBuffer: function (hRadio: Integer; lpDSPHeader: PDSPHdr; cbDSPHeader: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspBufferDone: function (hRadio: Integer; lpDSPHeader: PDSPHdr; cbDSPHeader: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspPause: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspResume: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspOutReset: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspInReset: function (hRadio: Integer): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}

  dspInOpen: function (hRadio: Integer; dwWaveFormat: Longint; hWindow: HWND): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  dspOutOpen: function (hRadio: Integer; dwWaveFormat: Longint; hWindow: HWND): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}

  { miscellaneous API functions }

  GetModeString: function (hRadio, iMode: Integer; lpString: PChar; iMaxLength: Integer): PChar; {$IFDEF WIN32} stdcall; {$ENDIF}
  {$IFDEF WIN32}
  GetModeStringA: function (hRadio, iMode: Integer; lpString: PAnsiChar; iMaxLength: Integer): PAnsiChar; stdcall;
  GetModeStringW: function (hRadio, iMode: Integer; lpString: PWideChar; iMaxLength: Integer): PWideChar; stdcall;
  {$ENDIF}

  OpenRadioCount: function: Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetDACValue: function (hRadio: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}

  EnableRadioNotification: function (hWindow: HWND; bEnabled: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}

  EnableAsyncMode: function (hRadio: Integer; hWindow: HWND): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}

  GetInterruptCount: function (hRadio: Integer): Integer; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetDmaStatus: function (hRadio: Integer; var Dma0Status, Dma3Status: Longint; ResetTiming: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
  GetRadioInfoModeList: procedure (hRadio: Integer; List: Pointer; Length: Integer); {$IFDEF WIN32} stdcall; {$ENDIF}
  Is16bitRadio: procedure (hRadio: Integer); {$IFDEF WIN32} stdcall; {$ENDIF}

  { ADU functions - n/a yet} 

function WRAPILoaded: Boolean;

implementation

function Null0: Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null0 := 0;
end;

function Null1(Param1: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null1 := 0;
end;

procedure Null1P(Param1: Integer) {$IFDEF WIN32} stdcall; {$ENDIF}
begin
end;

function Null2a(Param1, Param2: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null2a := 0;
end;

function Null2b(Param1: Integer; Param2: Longint): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null2b := 0;
end;

function Null3(Param1: Integer; Param2: Longint; Param3: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null3 := 0;
end;

procedure Null3P(Param1: Integer; Param2: Pointer; Param3: Integer); {$IFDEF WIN32} stdcall; {$ENDIF}
begin
end;

function Null4(Param1, Param2: Integer; Param3: Longint; Param4: Integer): Longint; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null4 := 0;
end;

function Null4b(Param1 : Integer; var Param2, Param3: Longint; Param4: Bool): Bool; {$IFDEF WIN32} stdcall; {$ENDIF}
begin
  Null4b := false;
end;

var
  hWRAPI: THandle;
  OldExitProc: Pointer;

function GetWRAPIProcAddress(ProcName: PChar; DefAddr: TFarProc): TFarProc;
var
  pa: TFarProc;
begin
  GetWRAPIProcAddress := DefAddr;
  if (hWRAPI > 32) then
  begin
    pa := GetProcAddress(hWRAPI, ProcName);
    if (pa <> nil) then
      GetWRAPIProcAddress := pa;
  end;
end;

function WRAPILoaded: Boolean;
begin
  WRAPILoaded := hWRAPI >= 32;
end;

procedure APIExitProc; {$IFNDEF WIN32} far; {$ENDIF}
begin
  ExitProc := OldExitProc;
  FreeLibrary(hWRAPI);
end;

procedure APIInit;
var
  OldSEM: Integer;
begin
  OldSEM := SetErrorMode(SEM_NOOPENFILEERRORBOX);
  {$IFDEF WIN32}
  hWRAPI := LoadLibrary('WRAPI32.DLL');
  {$ELSE}
  hWRAPI := LoadLibrary('WRAPI.DLL');
  {$ENDIF}
  SetErrorMode(OldSEM);

  if (hWRAPI >= 32) then
  begin
    OldExitProc := ExitProc;
    ExitProc := @APIExitProc;
  end;

  @OpenRadioDevice := GetWRAPIProcAddress('OpenRadioDevice', @Null1);
  @CloseRadioDevice := GetWRAPIProcAddress('CloseRadioDevice', @Null1);
  @GetRadioDeviceInfo := GetWRAPIProcAddress('GetRadioDeviceInfo', @Null2b);
  @GetSignalStrength := GetWRAPIProcAddress('GetSignalStrength', @Null1);
  @GetRawSignalStrength := GetWRAPIProcAddress('GetRawSignalStrength', @Null1);
  @LoadCalibrationData := GetWRAPIProcAddress('LoadCalibrationData', @Null1P);

  @SetFrequency := GetWRAPIProcAddress('SetFrequency', @Null2b);
  @SetMode := GetWRAPIProcAddress('SetMode', @Null2a);
  @SetVolume := GetWRAPIProcAddress('SetVolume', @Null2a);
  @SetAtten := GetWRAPIProcAddress('SetAtten', @Null2a);
  @SetMute := GetWRAPIProcAddress('SetMute', @Null2a);
  @SetPower := GetWRAPIProcAddress('SetPower', @Null2a);
  @SetScanMode := GetWRAPIProcAddress('SetScanMode', @Null2a);
  @SetBFOOffset := GetWRAPIProcAddress('SetBFOOffset', @Null2a);
  @SetIFShift := GetWRAPIProcAddress('SetIFShift', @Null2a);
  @SetAudioSource := GetWRAPIProcAddress('SetAudioSource', @Null2a);
  @SetDSPSource := GetWRAPIProcAddress('SetDSPSource', @Null2a);
  @SetAGC := GetWRAPIProcAddress('SetAGC', @Null2a);
  @SetIFGain := GetWRAPIProcAddress('SetIFGain', @Null2a);

  @GetFrequency := GetWRAPIProcAddress('GetFrequency', @Null1);
  @GetMode := GetWRAPIProcAddress('GetMode', @Null1);
  @GetVolume := GetWRAPIProcAddress('GetVolume', @Null1);
  @GetAtten := GetWRAPIProcAddress('GetAtten', @Null1);
  @GetMute := GetWRAPIProcAddress('GetMute', @Null1);
  @GetPower := GetWRAPIProcAddress('GetPower', @Null1);
  @GetScanMode := GetWRAPIProcAddress('GetScanMode', @Null1);
  @GetBFOOffset := GetWRAPIProcAddress('GetBFOOffset', @Null1);
  @GetIFShift := GetWRAPIProcAddress('GetIFShift', @Null1);
  @GetAudioSource := GetWRAPIProcAddress('GetAudioSource', @Null1);
  @GetDSPSource := GetWRAPIProcAddress('GetDSPSource', @Null1);
  @GetAGC := GetWRAPIProcAddress('GetAGC', @Null2a);
  @GetIFGain := GetWRAPIProcAddress('GetIFGain', @Null2a);

  @dspOpen := GetWRAPIProcAddress('dspOpen', @Null3);
  @dspClose := GetWRAPIProcAddress('dspClose', @Null1);
  @dspSendByte := GetWRAPIProcAddress('dspSendByte', @Null2a);
  @dspReadByte := GetWRAPIProcAddress('dspReadByte', @Null2b);
  @dspOutWrite := GetWRAPIProcAddress('dspOutWrite', @Null3);
  @dspInAddBuffer := GetWRAPIProcAddress('dspInAddBuffer', @Null3);
  @dspBufferDone := GetWRAPIProcAddress('dspBufferDone', @Null3);
  @dspPause := GetWRAPIProcAddress('dspPause', @Null1);
  @dspResume := GetWRAPIProcAddress('dspResume', @Null1);
  @dspOutReset := GetWRAPIProcAddress('dspOutReset', @Null1);
  @dspInReset := GetWRAPIProcAddress('dspInReset', @Null1);

  @dspInOpen := GetWRAPIProcAddress('dspInOpen', @Null3);
  @dspOutOpen := GetWRAPIProcAddress('dspOutOpen', @Null3);

  {$IFDEF WIN32}
  @GetModeStringA := GetWRAPIProcAddress('GetModeStringA', @Null4);
  @GetModeStringW := GetWRAPIProcAddress('GetModeStringW', @Null4);
  @GetModeString := @GetModeStringA;
  {$ELSE}
  @GetModeString := GetWRAPIProcAddress('GetModeString', @Null4);
  {$ENDIF}

  @OpenRadioCount := GetWRAPIProcAddress('OpenRadioCount', @Null0);
  @GetDACValue := GetWRAPIProcAddress('GetDACValue', @Null1);

  @EnableRadioNotification := GetWRAPIProcAddress('EnableRadioNotification', @Null2a);

  @EnableAsyncMode := GetWRAPIProcAddress('EnableAsyncMode', @Null2a);

  @GetInterruptCount := GetWRAPIProcAddress('GetInterruptCount', @Null1);
  @GetDmaStatus := GetWRAPIProcAddress('GetDmaStatus', @Null4b);
  @GetRadioInfoModeList := GetWRAPIProcAddress('GetRadioInfoModeList', @Null3P);
  @Is16bitRadio := GetWRAPIProcAddress('Is16bitRadio', @Null1P);
end;

begin
  APIInit;
end.
